pytest-8.3.3
=======================================

pytest 8.3.3 has just been released to PyPI.

This is a bug-fix release, being a drop-in replacement. To upgrade::

  pip install --upgrade pytest

The full changelog is available at https://docs.pytest.org/en/stable/changelog.html.

Thanks to all of the contributors to this release:

* Anthony Sottile
* Avasam
* Bruno Oliveira
* Christian Clauss
* Eugene Mwangi
* Freya Bruhin
* GTowers1
* Nauman Ahmed
* Pierre Sassoulas
* Reagan Lee
* Ronny Pfannschmidt
* Stefaan Lippens
* Sviatoslav Sydorenko (Святослав Сидоренко)
* dongfangtianyu


Happy testing,
The pytest Development Team
